@@ -311,6 +311,10 @@ void        meta_window_raise              (MetaWindow  *window);
 META_EXPORT
 void        meta_window_lower              (MetaWindow  *window);
 
+META_EXPORT
+void        meta_window_lower_with_transients (MetaWindow *window,
+                                               uint32_t    timestamp);
+
 META_EXPORT
 const char *meta_window_get_title (MetaWindow *window);
 
@@ -328,7 +332,7 @@ META_EXPORT
 guint32     meta_window_get_user_time (MetaWindow *window);
 
 META_EXPORT
-int         meta_window_get_pid (MetaWindow *window);
+pid_t       meta_window_get_pid (MetaWindow *window);
 
 META_EXPORT
 const char *meta_window_get_client_machine (MetaWindow *window);
@@ -339,6 +343,9 @@ gboolean    meta_window_is_remote (MetaWindow *window);
 META_EXPORT
 gboolean    meta_window_is_attached_dialog (MetaWindow *window);
 
+META_EXPORT
+gboolean    meta_window_has_attached_dialogs (MetaWindow *window);
+
 META_EXPORT
 const char *meta_window_get_mutter_hints (MetaWindow *window);
 
@@ -446,4 +453,7 @@ uint64_t meta_window_get_id (MetaWindow *window);
 META_EXPORT
 MetaWindowClientType meta_window_get_client_type (MetaWindow *window);
 
+META_EXPORT
+gboolean meta_window_has_pointer (MetaWindow *window);
+
 #endif
